Evaluation Metrics
==================

.. currentmodule:: hpipy.utils.metrics

.. autosummary::
   :toctree: _autosummary
   :template: class.rst

   accuracy
   volatility
   revision
   series_accuracy
   series_volatility
